
# Slot: equals_number


the slot must have range of a number and the value of the slot must equal the specified value

URI: [linkml:equals_number](https://w3id.org/linkml/equals_number)


## Domain and Range

None &#8594;  <sub>0..1</sub> integer

## Parents

 *  is_a: value_specification_constant

## Children


## Used by

 * anonymous_slot_expression
 * anonymous_type_expression
 * slot_definition
 * slot_expression
 * type_definition
 * type_expression
